@@ -1,5 +1,4 @@
-use aead::{generic_array::GenericArray, Error};
-use cipher::consts::U16;
+use aead::{consts::U16, generic_array::GenericArray, Error};
 use core::convert::TryInto;
 use core::marker::PhantomData;
 use subtle::ConstantTimeEq;
@@ -333,7 +332,7 @@ impl<P: Parameters> Core<P> {
         self.process_decrypt_inplace(ciphertext);
 
         let tag = self.process_final();
-        if tag.ct_eq(expected_tag).unwrap_u8() == 1 {
+        if bool::from(tag.ct_eq(expected_tag)) {
             Ok(())
         } else {
             Err(Error)
